# Text Representation

Text representation commands are used to determine how objects are printed on the Python command line.

## Other Classes

```{eval-rst}

.. toggle::

    .. automodule:: abaqus.TextRepresentation.redentABQ
        :members:

    .. automodule:: abaqus.TextRepresentation.textRepr
        :members:

    .. autoclass:: abaqus.TextRepresentation.TextReprOptions.TextReprOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
